@@ -34,6 +34,7 @@ enum {
 	AUTOBROWSE,
 	AUTOBURN,
 	AUTOBURN_AUDIO_CD_COMMAND,
+	AUTOBURN_PHOTO_CD_COMMAND,
 	AUTOBURN_DATA_CD_COMMAND,
 	AUTOIPOD,
 	AUTOIPOD_COMMAND,
@@ -71,6 +72,7 @@ static struct {
 	{ GCONF_ROOT "autobrowse",                TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoburn",                  TYPE_BOOL,   NULL, FALSE },
 	{ GCONF_ROOT "autoburn_audio_cd_command", TYPE_STRING, NULL, FALSE },
+	{ GCONF_ROOT "autoburn_photo_cd_command", TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoburn_data_cd_command",  TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoipod",                  TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoipod_command",          TYPE_STRING, NULL, FALSE },
